@@ -7,7 +7,7 @@ magenta = "magenta"
 black = "black"
 white = "white"
 
-def color(text, color):
+def print(text, color):
     if color == "reset":
         print("\u001b[0m" + text)
     elif color == "red":
